
# MarzbanAPI Client

[![Stars](https://img.shields.io/github/stars/sm1ky/marzban_api.svg?style=social)](https://github.com/sm1ky/marzban_api/stargazers)
[![Forks](https://img.shields.io/github/forks/sm1ky/marzban_api.svg?style=social)](https://github.com/sm1ky/marzban_api/network/members)
[![Issues](https://img.shields.io/github/issues/sm1ky/marzban_api.svg)](https://github.com/sm1ky/marzban_api/issues)
[![Supported python versions](https://img.shields.io/pypi/pyversions/marzban.svg)](https://pypi.python.org/pypi/marzban)
[![Downloads](https://img.shields.io/pypi/dm/marzban.svg)](https://pypi.python.org/pypi/marzban)
[![PyPi Package Version](https://img.shields.io/pypi/v/marzban)](https://pypi.python.org/pypi/marzban)
[![Supported Marzban Version](https://img.shields.io/github/v/release/Gozargah/Marzban?label=Marzban)](https://github.com/Gozargah/Marzban)
[![Publish Python Package](https://github.com/sm1ky/marzban_api/actions/workflows/deploy.yml/badge.svg?branch=production)](https://github.com/sm1ky/marzban_api/actions/workflows/deploy.yml)


**MarzbanAPI Client** is an asynchronous Python library designed for interacting with [Marzban](https://github.com/Gozargah/Marzban). It provides comprehensive methods for managing administrators, users, nodes, and system statistics.
It supports **Marzban version 0.8.4**, providing comprehensive methods for managing administrators, users, nodes, and system statistics.

To see the list of supported Marzban versions and corresponding API compatibility, check out our [Supported Versions](https://github.com/sm1ky/marzban_api/blob/production/.readme/supported_version.md) file.

## Installation

To install the latest version of the library, use:

```bash
pip install marzban
```

## Project Links
- **PyPI**: [marzban](https://pypi.org/project/marzban/)
- **GitHub Repository**: [marzban_api](https://github.com/sm1ky/marzban_api)

## Detailed Documentation

For detailed documentation and usage examples, select your preferred language below:

- [English](https://github.com/sm1ky/marzban_api/blob/production/.readme/README_en.md)
- [Русский (Russian)](https://github.com/sm1ky/marzban_api/blob/production/.readme/README_ru.md)

## Contributing

We welcome contributions! If you encounter any issues or have suggestions for improvements, please feel free to [open an issue](https://github.com/sm1ky/marzban_api/issues) or submit a Pull Request (PR).

## Support

If you have any questions or need assistance, you can contact the author via:
- **Email**: [contant@sm1ky.com](mailto:contant@sm1ky.com)
- **Telegram**: [@sm1ky](https://t.me/sm1ky)

## License

This project is licensed under the MIT License. For more details, refer to the [LICENSE file](https://github.com/sm1ky/marzban_api/blob/production/LICENSE).
